autorag.data.beta.schema package
================================

Submodules
----------

autorag.data.beta.schema.data module
------------------------------------

.. automodule:: autorag.data.beta.schema.data
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: autorag.data.beta.schema
   :members:
   :undoc-members:
   :show-inheritance:
